OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Inbäddat meddelande %s",
    "Important mail" : "Viktig e-post",
    "No message found yet" : "Inget meddelande har ännu hittats",
    "Set up an account" : "Skapa ett konto",
    "Unread mail" : "Oläst e-post",
    "Important" : "Viktigt",
    "Work" : "Arbete",
    "Personal" : "Personligt",
    "To Do" : "Att göra",
    "Later" : "Senare",
    "Mail" : "E-post",
    "Mails" : "E-post",
    "💌 A mail app for Nextcloud" : "En e-post-app för Nextcloud",
    "Drafts are saved in:" : "Utkast sparas i:",
    "Sent messages are saved in:" : "Skickade meddelanden sparas i:",
    "Deleted messages are moved in:" : "Raderade meddelanden flyttas till:",
    "Connecting" : "Ansluter",
    "Save" : "Spara",
    "Connect" : "Anslut",
    "Password required" : "Lösenord krävs",
    "IMAP username or password is wrong" : "IMAP-användarnamn eller lösenord är felaktigt",
    "SMTP username or password is wrong" : "SMTP-användarnamn eller lösenord är felaktigt",
    "IMAP connection failed" : "IMAP-anslutning misslyckades",
    "SMTP connection failed" : "SMTP-anslutning misslyckades",
    "Auto" : "Auto",
    "Name" : "Namn",
    "Mail address" : "E-postadress",
    "name@example.org" : "namn@example.org",
    "Please enter an email of the format name@example.com" : "Ange en e-postadress på formen name@example.com",
    "Password" : "Lösenord",
    "Manual" : "Manuellt",
    "IMAP Settings" : "IMAP-inställningar",
    "IMAP Host" : "IMAP-värd",
    "IMAP Security" : "IMAP-säkerhet",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "Användare",
    "IMAP Password" : "IMAP-lösenord",
    "SMTP Settings" : "SMTP-inställningar",
    "SMTP Host" : "SMTP-värd",
    "SMTP Security" : "SMTP-säkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-användare",
    "SMTP Password" : "SMTP-lösenord",
    "Account settings" : "Kontoinställningar",
    "Aliases" : "Alias",
    "Signature" : "Signatur",
    "A signature is added to the text of new messages and replies." : "En signatur läggs till i texten för nya meddelanden och svar.",
    "Writing mode" : "Skrivläge",
    "Preferred writing mode for new messages and replies." : "Föredraget skrivläge för nya meddelanden och svar.",
    "Default folders" : "Standardmappar",
    "Filters" : "Filter",
    "Mail server" : "E-postserver",
    "Update alias" : "Uppdatera alias",
    "Delete alias" : "Radera alias",
    "Go back" : "Gå tillbaka",
    "Change name" : "Byt namn",
    "Email address" : "E-postadress",
    "Add alias" : "Lägg till alias",
    "Create alias" : "Skapa alias",
    "Cancel" : "Avbryt",
    "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp.",
    "Could not update preference" : "Kunde inte uppdatera inställningar",
    "Mail settings" : "E-postinställningar",
    "Accounts" : "Konton",
    "Add mail account" : "Lägg till e-postkonto",
    "General" : "Allmänt",
    "Layout" : "Layout",
    "Sorting" : "Sortering",
    "Newest" : "Nyast",
    "Oldest" : "Äldst",
    "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon som profilbild",
    "Register as application for mail links" : "Registrera som app för e-postlänkar",
    "Register" : "Registrera",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
    "Trusted senders" : "Betrodda avsändare",
    "Looking for a way to encrypt your emails?" : "Söker du efter ett sätt att kryptera meddelanden?",
    "About" : "Om",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Compose new message" : "Skapa nytt meddelande",
    "Newer message" : "Nyare meddelande",
    "Older message" : "Äldre meddelande",
    "Toggle star" : "Växla stjärna",
    "Toggle unread" : "Visa/dölj oläst",
    "Archive" : "Arkivera",
    "Delete" : "Ta bort",
    "Search" : "Sök",
    "Send" : "Skicka",
    "Refresh" : "Uppdatera",
    "Send later" : "Skicka senare",
    "Message {id} could not be found" : "Meddelandet {id} hittades inte",
    "From" : "Från",
    "Select account" : "Välj konto",
    "To" : "Till",
    "Contact or email address …" : "Kontakt eller e-postadress …",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Ämne",
    "Subject …" : "Ämne …",
    "This message came from a noreply address so your reply will probably not be read." : "Det här meddelandet kom från en noreply adress så ditt svar kommer förmodligen inte att läsas.",
    "The following recipients do not have a PGP key: {recipients}." : "Följande mottagare har ingen PGP-nyckel: {recipients}.",
    "Write message …" : "Skriv meddelande ...",
    "Saving draft …" : "Sparar utkast ...",
    "Error saving draft" : "Kunde inte spara utkast",
    "Draft saved" : "Utkast sparat",
    "Save draft" : "Spara utkast",
    "Discard & close draft" : "Stäng och radera utkast",
    "Enable formatting" : "Aktivera formatering",
    "Upload attachment" : "Ladda upp bilaga",
    "Add attachment from Files" : "Lägg till bilaga från Filer",
    "Smart picker" : "Smart picker",
    "Request a read receipt" : "Begär läskvitto",
    "Encrypt message with Mailvelope" : " Kryptera meddelande med \"Mailvelope\"",
    "Send now" : "Skicka nu",
    "Tomorrow morning" : "Imorgon bitti",
    "Tomorrow afternoon" : "Imorgon eftermiddag",
    "Monday morning" : "Måndag morgon",
    "Custom date and time" : "Anpassat datum och tid",
    "Enter a date" : "Ange datum",
    "Choose" : "Välj",
    "Choose a file to add as attachment" : "Välj en fil att lägga som bilaga",
    "Choose a file to share as a link" : "Välj en fil att dela som länk",
    "_{count} attachment_::_{count} attachments_" : ["{count} bilaga","{count} bilagor"],
    "Confirm" : "Bekräfta",
    "Plain text" : "Oformaterad text",
    "Rich text" : "Formaterad text",
    "No messages in this mailbox" : "Inga meddelanden i den här brevlådan",
    "No messages" : "Inga meddelanden",
    "Blind copy recipients only" : "Endast mottagare för blindkopior",
    "No subject" : "Ingen ämnesrad",
    "Later today – {timeLocale}" : "Senare idag – {timeLocale}",
    "Set reminder for later today" : "Ställ in påminnelse för senare idag",
    "Tomorrow – {timeLocale}" : "Imorgon – {timeLocale}",
    "Set reminder for tomorrow" : "Ställ in påminnelse för imorgon",
    "This weekend – {timeLocale}" : "Den här helgen – {timeLocale}",
    "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
    "Next week – {timeLocale}" : "Nästa vecka – {timeLocale}",
    "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
    "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
    "Could not delete message" : "Kunde inte radera meddelande",
    "Could not archive message" : "Kunde inte arkivera meddelandet",
    "Draft: " : "Utkast:",
    "Unfavorite" : "Inte favorit",
    "Favorite" : "Favorit",
    "Unread" : "Oläst",
    "Read" : "Läs",
    "Unimportant" : "Oviktigt",
    "Mark not spam" : "Markera som ej skräppost",
    "Mark as spam" : "Markera som skräppost",
    "Edit tags" : "Redigera taggar",
    "Move thread" : "Flytta tråd",
    "Archive thread" : "Arkivera tråd",
    "Delete thread" : "Radera tråd",
    "More actions" : "Fler händelser",
    "Back" : "Tillbaka",
    "Edit as new message" : "Redigera som nytt meddelande",
    "Create event" : "Skapa evenemang",
    "Create task" : "Skapa uppgift",
    "Load more" : "Ladda mer",
    "_Mark {number} read_::_Mark {number} read_" : ["Markera {number} meddelande som läst","Markera {number} meddelanden som lästa"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Markera {number} meddelande som oläst","Markera {number} meddelanden som olästa"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Markera {number} meddelande som viktigt","Markera {number} meddelanden som viktiga"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Markera {number} meddelande som oviktigt","Markera {number} meddelanden som oviktiga"],
    "_Unselect {number}_::_Unselect {number}_" : ["Avmarkera {number}","Avmarkera {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Flytta {number} tråd","Flytta {number} trådar"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Vidarebefordra {number} som bilaga","Vidarebefordra {number} som bilagor"],
    "Report this bug" : "Rapportera detta fel",
    "Event created" : "Evenemang skapat",
    "Could not create event" : "Kunde inte skapa händelse",
    "All day" : "Hela dagen",
    "Description" : "Beskrivning",
    "Create" : "Skapa",
    "Select" : "Välj",
    "Comment" : "Kommentar",
    "Accept" : "Acceptera",
    "Decline" : "Avböj",
    "More options" : "Fler alternativ",
    "individual" : "individ",
    "domain" : "domän",
    "Remove" : "Ta bort",
    "email" : "e-post",
    "Itinerary for {type} is not supported yet" : "Resplan för {type} stöds inte än",
    "Could not open mailbox" : "Kunde inte öppna brevlådan",
    "Loading messages …" : "Läser in meddelanden …",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexera dina meddelanden. Det kan ta lite längre tid för större brevlådor.",
    "Choose target mailbox" : "Välj markerad inkorg",
    "No more submailboxes in here" : "Inga fler undermappar här",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Meddelanden kommer automatiskt att markeras som viktiga baserat på vilka meddelanden du interagerade med eller har markerat som viktiga. I början kan du behöva ändra vikten manuellt, men det kommer att förbättras med tiden.",
    "Important info" : "Viktig info",
    "Other" : "Övrigt",
    "Notify the sender" : "Meddela avsändaren",
    "You sent a read confirmation to the sender of this message." : "Du har skickat ett läskvitto till meddelandets avsändare.",
    "Forward" : "Vidarebefordra",
    "Move message" : "Flytta meddelande",
    "Translate" : "Översätt",
    "Forward message as attachment" : "Vidarebefordra medelande som bilaga",
    "View source" : "Visa källa",
    "Message body" : "Meddelandetext",
    "Unnamed" : "Namnlös",
    "Embedded message" : "Inbäddat meddelande",
    "Choose a folder to store the attachment in" : "Välj en mapp att spara den bifogade filen i",
    "Import into calendar" : "Importera till kalender",
    "Download attachment" : "Hämta bilaga",
    "Save to Files" : "Spara till filer",
    "Choose a folder to store the attachments in" : "Välj en mapp att spara bifogade filer i",
    "Save all to Files" : "Spara alla i filer",
    "Download Zip" : "Ladda ner arkiv",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Detta meddelande är krypterat med PGP. Installera \"Mailvelope\" för att dekryptera det.",
    "The images have been blocked to protect your privacy." : "Bilderna har blockerats av säkerhetsskäl.",
    "Show images" : "Visa bilder",
    "Show images temporarily" : "Visa bilder den här gången",
    "Always show images from {sender}" : "Visa alltid bilder från {sender}",
    "Always show images from {domain}" : "Visa alltid bilder från {domain}",
    "Message frame" : "Meddelande ram",
    "Quoted text" : "Citerad text",
    "Move" : "Flytta",
    "Moving" : "Flyttar",
    "Moving thread" : "Flyttar tråd",
    "Moving message" : "Flyttar meddelande",
    "Loading …" : "Läser in ...",
    "Not supported by the server" : "Stöds ej av  servern",
    "{usage} of {limit} used" : "{usage} av {limit} använt",
    "Remove account" : "Ta bort konto",
    "Remove {email}" : "Ta bort {email}",
    "Quota" : "Kvot",
    "Show only subscribed mailboxes" : "Visa endast prenumererade brevlådor",
    "Add mailbox" : "Lägg till brevlåda",
    "Saving" : "Sparar",
    "Move up" : "Flytta upp",
    "Move down" : "Flytta ner",
    "Show all subscribed mailboxes" : "Visa alla prenumererade brevlådor",
    "Show all mailboxes" : "Visa alla brevlådor",
    "Collapse mailboxes" : "Minimera brevlådor",
    "_{total} message_::_{total} messages_" : ["{total} meddelande","{total} meddelanden"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} av {total} oläst","{unread} av {total} oläst"],
    "Delete mailbox" : "Radera brevlåda",
    "An error occurred, unable to rename the mailbox." : "Ett fel inträffade, det gick inte att byta namn på brevlådan.",
    "Mark all as read" : "Markera alla som lästa",
    "Mark all messages of this mailbox as read" : "Markera alla meddelanden i den här brevlådan som lästa",
    "Rename" : "Byt namn",
    "Clear cache" : "Rensa cachen",
    "Clear locally cached data, in case there are issues with synchronization." : "Rensa lokalt cachad data, ifall det finns problem med synkronisering.",
    "Subscribed" : "Prenumeration aktiverad",
    "Sync in background" : "Synkronisera i bakgrunden",
    "Outbox" : "Utkorg",
    "New message" : "Nytt meddelande",
    "Edit message" : "Redigera meddelande",
    "Draft" : "Utkast",
    "Reply" : "Svara",
    "Error sending your message" : "Ett fel inträffade när ditt meddelande skulle skickas",
    "Retry" : "Försök igen",
    "Uploading attachments …" : "Laddar upp bilagor ...",
    "Sending …" : "Skickar ...",
    "Send anyway" : "Skicka ändå",
    "First day" : "Första dagen",
    "Message" : "Meddelande",
    "Oh Snap!" : "Hoppsan!",
    "Could not open outbox" : "Kunde inte öppna utkorgen",
    "Contacts with this address" : "Kontakter med den här adressen",
    "Add to Contact" : "Lägg till i Kontakter",
    "New Contact" : "Ny kontakt",
    "Copy to clipboard" : "Kopiera till urklipp",
    "Contact name …" : "Kontaktnamn …",
    "Add" : "Lägg till",
    "Show less" : "Visa mindre",
    "Show more" : "Visa mer",
    "Clear" : "Rensa",
    "Search in mailbox" : "Sök i brevlådan",
    "Close" : "Stäng",
    "Search parameters" : "Sökparametrar",
    "Body" : "Textyta",
    "Date" : "Datum",
    "Pick a start date" : "Välj ett startdatum",
    "Pick an end date" : "Välj ett slutdatum",
    "Tags" : "Taggar",
    "Select tags" : "Välj taggar",
    "Last 7 days" : "Senaste 7 dagarna",
    "Custom" : "Anpassad",
    "Signature …" : "Signatur …",
    "Save signature" : "Spara signatur",
    "Place signature above quoted text" : "Placera signaturen ovanför citerad text",
    "An error occurred, unable to rename the tag." : "Ett fel uppstod, kunde inte byta taggens namn.",
    "Delete tag" : "Radera tagg",
    "Tag already exists" : "Taggen finns redan",
    "An error occurred, unable to create the tag." : "Ett fel uppstod, kunde inte spara taggen.",
    "Add default tags" : "Lägg till standardtaggar",
    "Add tag" : "Lägg till tagg",
    "Saving tag …" : "Sparar tagg …",
    "Could not load your message thread" : "Det gick inte att ladda meddelandetråden",
    "Not found" : "Hittades inte",
    "Reply all" : "Svara alla",
    "Unsubscribe" : "Avsluta prenumeration",
    "Reply to sender only" : "Svara endast avsändaren",
    "Mark as unread" : "Markera som oläst",
    "Mark as read" : "Markera som läst",
    "Archive message" : "Arkivera meddelandet",
    "Delete message" : "Radera meddelande",
    "Message source" : "Meddelandekälla",
    "The message could not be translated" : "Meddelandet kunde inte översättas",
    "Translation copied to clipboard" : "Översättningen har kopierats till urklipp",
    "Translation could not be copied" : "Översättningen kunde inte kopieras",
    "Translate message" : "Översätt meddelande",
    "Source language to translate from" : "Språk att översätta från",
    "Translate from" : "Översätt från",
    "Target language to translate into" : "Språk att översätta till",
    "Translate to" : "Översätt till",
    "Translating" : "Översätter",
    "Copy translated text" : "Kopiera översatt text",
    "No senders are trusted at the moment." : "Inga avsändare är betrodda för tillfället.",
    "Untitled event" : "Namnlös händelse",
    "(organizer)" : "(arrangör)",
    "Import into {calendar}" : "Importera till {calendar}",
    "Event imported into {calendar}" : "Händelse importerad till {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flyg {flightNr} från {depAirport} till {arrAirport}",
    "Airplane" : "Flygplan",
    "Reservation {id}" : "Bokning {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} från {depStation} till {arrStation}",
    "Train from {depStation} to {arrStation}" : "Tåg från {depStation} till {arrStation}",
    "Train" : "Tåg",
    "Delete filter" : "Ta bort filter",
    "Operator" : "Operatör",
    "Filter name" : "Filternamn",
    "Actions" : "Funktioner",
    "New action" : "Ny åtgärd",
    "Priority" : "Prioritet",
    "Mail app" : "Mail-app",
    "The mail app allows users to read mails on their IMAP accounts." : "Mail-appen tillåter användare att läsa e-post på sina IMAP-konton.",
    "Reset" : "Återställ",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klienthemlighet",
    "Email: {email}" : "E-post: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} på {host}:{port} ({ssl}-krypterat)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} på {host}:{port} ({ssl}-krypterat)",
    "IMAP" : "IMAP",
    "User" : "Användare",
    "Host" : "Server",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Save Config" : "Spara inställningar",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% och %EMAIL% kommer ersättas av användarens UID och e-post",
    "With the settings above, the app will create account settings in the following way:" : "Med inställningarna ovan skapar appen kontoinställningar på följande sätt:",
    "E-mail address" : "E-postadress",
    "Valid until" : "Giltigt till",
    "Delete certificate" : "Ta bort certifikat",
    "Certificate" : "Certifikat",
    "Submit" : "Skicka",
    "Account connected" : "Konto anslutet",
    "Connect your mail account" : "Anslut ditt e-postkonto",
    "All" : "Alla",
    "Drafts" : "Utkast",
    "Favorites" : "Favoriter",
    "Priority inbox" : "Prioriterad inkorg",
    "All inboxes" : "Alla inkorgar",
    "Inbox" : "Inkorg",
    "Junk" : "Skräp",
    "Sent" : "Skickat",
    "Trash" : "Papperskorg",
    "Error while sharing file" : "Fel vid delning av fil",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
    "Nextcloud Mail" : "Nextcloud E-post",
    "Discard changes" : "Släng ändringar",
    "Attachments were not copied. Please add them manually." : "Bifogade filer kopierades inte, lägg till dem manuellt.",
    "Message sent" : "Meddelande skickat",
    "Could not load {tag}{name}{endtag}" : "Kunde inte läsa in {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det uppstod ett problem vis inläsning av {tag}{name}{endtag}",
    "Could not load your message" : "Kunde inte läsa in ditt meddelande",
    "Could not load the desired message" : "Kunde inte läsa in önskat meddelande",
    "Could not load the message" : "Kunde inte läsa in meddelandet",
    "Error loading message" : "Fel vid inläsning av meddelande",
    "Forwarding to %s" : "Vidarebefordrar till %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
    "Redirect" : "Omdirigera",
    "The link leads to %s" : "Länken pekar mot %s",
    "Continue to %s" : "Fortsätt till %s"
},
"nplurals=2; plural=(n != 1);");
